// src/logger.ts
var Logger = class {
  #debug;
  constructor(debug = false) {
    this.#debug = debug;
  }
  log(message, color = "\x1B[30m%s\x1B[0m") {
    if (!this.#debug) {
      return;
    }
    console.log(color, message);
  }
  red(message) {
    this.log(message, "\x1B[31m%s\x1B[0m");
  }
  green(message) {
    this.log(message, "\x1B[32m%s\x1B[0m");
  }
  yellow(message) {
    this.log(message, "\x1B[33m%s\x1B[0m");
  }
  blue(message) {
    this.log(message, "\x1B[34m%s\x1B[0m");
  }
  magenta(message) {
    this.log(message, "\x1B[35m%s\x1B[0m");
  }
  cyan(message) {
    this.log(message, "\x1B[36m%s\x1B[0m");
  }
};

// src/utilities.ts
import fs from "fs";
import path from "path";
function createOutDir(outDir) {
  if (outDir !== "./" && !fs.existsSync(outDir)) {
    fs.mkdirSync(outDir, { recursive: true });
  }
}
function saveFile(outDir, fileName, contents) {
  const outputPath = path.join(outDir, fileName);
  fs.writeFileSync(outputPath, contents);
  return outputPath;
}

// src/module-path-resolver.ts
var log;
var userOptions = {
  outdir: "./",
  fileName: "custom-elements.json"
};
function resolveModulePaths(cem, options = {}) {
  log = new Logger(options.debug);
  if (options.skip) {
    log.yellow("[module-path-resolver] - Skipped");
    return;
  }
  updateOptions(options);
  log.log("[module-path-resolver] - Updating Custom Elements Manifest...");
  updateCemModules(cem);
  if (!options.usedByPlugin) {
    createOutDir(userOptions.outdir);
    saveFile(
      userOptions.outdir,
      userOptions.fileName,
      JSON.stringify(cem, null, 2)
    );
  }
  log.green("[module-path-resolver] - Custom Elements Manifest updated.");
}
function updateOptions(options = {}) {
  userOptions = { ...userOptions, ...options };
}
function updateCemModules(cem) {
  cem.modules.forEach((module) => {
    const ogPath = module.path;
    const ces = module.declarations?.filter(
      (d) => d.customElement
    );
    if (ces.length) {
      ces.forEach((ce) => {
        if (userOptions.modulePathTemplate) {
          module.path = userOptions.modulePathTemplate(
            ogPath,
            ce.name,
            ce.tagName
          );
          log.log(
            `[module-path-resolver] - Updated ${ce.name}'s module path: ${module.path}`
          );
        }
        if (userOptions.typeDefinitionPathTemplate) {
          const typeDefPath = userOptions.typeDefinitionPathTemplate(
            ogPath,
            ce.name,
            ce.tagName
          );
          module["typeDefinitionPath"] = typeDefPath;
          log.log(
            `[module-path-resolver] - Added type definition path to ${ce.name}: ${typeDefPath}`
          );
        }
        if (userOptions.definitionPathTemplate) {
          const exportPath = userOptions.definitionPathTemplate(
            ogPath,
            ce.name,
            ce.tagName
          );
          cem.modules.push({
            kind: "javascript-module",
            path: exportPath,
            deprecated: ce.deprecated || false,
            declarations: [],
            exports: [
              {
                kind: "custom-element-definition",
                name: ce.tagName || ce.name,
                declaration: {
                  name: ce.name,
                  module: module.path
                }
              }
            ]
          });
          log.log(
            `[module-path-resolver] - Added definition export for ${ce.name}: ${exportPath}`
          );
        }
      });
    }
  });
}

// src/cem-plugin.ts
function modulePathResolverPlugin(options) {
  return {
    name: "@wc-toolkit/module-path-resolver",
    packageLinkPhase({ customElementsManifest }) {
      options.usedByPlugin = true;
      resolveModulePaths(customElementsManifest, options);
    }
  };
}
export {
  modulePathResolverPlugin,
  resolveModulePaths
};
